from distutils.core import setup

setup(
    name = "sahir_py_std",
    version = "0.5",
    packages=['sahirPyStd'],
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    long_description=open('README.txt').read()
)
